@@ -74,13 +74,7 @@ public class BitbucketServerURLParser {
     if (!isNullOrEmpty(bitbucketEndpoints)) {
       for (String bitbucketEndpoint : Splitter.on(",").split(bitbucketEndpoints)) {
         String trimmedEndpoint = StringUtils.trimEnd(bitbucketEndpoint, '/');
-        URI uri = URI.create(trimmedEndpoint);
-        bitbucketUrlPatternTemplates.forEach(
-            t -> {
-              String scheme = t.contains("git@") ? "ssh" : uri.getScheme();
-              String host = uri.getHost() + uri.getPath();
-              bitbucketUrlPatterns.add(Pattern.compile(format(t, scheme, host)));
-            });
+        bitbucketUrlPatterns.addAll(getUrlPatterns(trimmedEndpoint));
       }
     }
   }
@@ -114,11 +108,28 @@ public class BitbucketServerURLParser {
       // If Bitbucket server URL is not configured try to find it in a manually added user namespace
       // token.
       isUserTokenPresent(url)
-          // Try to call an API request to see if the URL matches Bitbucket.
-          || isApiRequestRelevant(url);
+          // Try to call an API request to see if the URL matches Bitbucket Server.
+          || (isApiRequestRelevant(url)
+              // Also check if the URL matches the Bitbucket Server url pattern.
+              && getUrlPatterns(getServerUrl(url)).stream()
+                  .anyMatch(pattern -> pattern.matcher(url).matches()));
     }
   }
 
+  private List<Pattern> getUrlPatterns(String url) {
+    URI uri = URI.create(url);
+    ArrayList<Pattern> patterns = new ArrayList<>();
+    bitbucketUrlPatternTemplates.forEach(
+        t -> {
+          String scheme = t.contains("git@") ? "ssh" : uri.getScheme();
+          String host =
+              uri.getHost() + (uri.getPort() > 0 ? ":" + uri.getPort() : "") + uri.getPath();
+          ;
+          patterns.add(Pattern.compile(format(t, scheme, host)));
+        });
+    return patterns;
+  }
+
   private boolean isApiRequestRelevant(String repositoryUrl) {
     try {
       HttpBitbucketServerApiClient bitbucketServerApiClient =
